==> ejc-bid-api-3.0.0-20211124.073754-29-sources.jar: com/ejianc/business/bid/vo/summaryVO.java <==
package com.ejianc.business.bid.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 *   投标总结 
 * 
 * @author generator
 * 
 */
@ApiModel("  投标总结 ")
public class summaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("所属组织")
    private java.lang.Long orgId;
    @ApiModelProperty("所属组织名称")
    private java.lang.String orgName;
    @ApiModelProperty("单据编码")
    private java.lang.String billCode;
    @ApiModelProperty("单据状态")
    private java.lang.Integer billState;
    @ApiModelProperty("工程id")
    private java.lang.Long enrollId;
    @ApiModelProperty("工程编码")
    private java.lang.String engineeringCode;
    @ApiModelProperty("工程名称")
    private java.lang.String engineeringName;
    @ApiModelProperty("开标日期(格式：yyyy-mm-dd)")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date openTenderDate;
    @ApiModelProperty("评标办法id  (自定义档案)")
    private java.lang.Long bidEvaluationId;
    @ApiModelProperty("评标办法")
    private java.lang.String bidEvaluationMethod;
    @ApiModelProperty("项目负责人")
    private java.lang.String projectLeader;
    @ApiModelProperty("建造师")
    private java.lang.String architect;
    @ApiModelProperty("投标结果 0 已中标 1 未中标")
    private java.lang.Integer bidResult;
    @ApiModelProperty("中标单位id")
    private java.lang.Long bidWinnerId;
    @ApiModelProperty("中标单位")
    private java.lang.String bidWinner;
    @ApiModelProperty("施工项目部id")
    private java.lang.String constructionProjectDepartmentId;
    @ApiModelProperty("施工项目部")
    private java.lang.String constructionProjectDepartment;
    @ApiModelProperty("开标地点")
    private java.lang.String bidOpeningPlace;
    @ApiModelProperty("中标日期(格式：yyyy-mm-dd)")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date winBiddingDate;
    @ApiModelProperty("报价形式 0:总价 1:费率")
    private java.lang.String quotationForm;
    @ApiModelProperty("中标金额  （单位万元）")
    private java.math.BigDecimal bidMmy;
    @ApiModelProperty("招标控制价（单位万元）")
    private java.math.BigDecimal biddingControlMmy;
    @ApiModelProperty("报价下浮率（控制价）% ")
    private java.math.BigDecimal quoteLowerRate;
    @ApiModelProperty("投标报价费率 ")
    private java.math.BigDecimal bidQuotationRate;
    @ApiModelProperty("招标控制价费率")
    private java.math.BigDecimal biddingControlRate;
    @ApiModelProperty("报价下浮率（控制价）%")
    private java.math.BigDecimal controlQuoteLowerRate;
    @ApiModelProperty("工期")
    private java.math.BigDecimal duration;
    @ApiModelProperty("投标单位id")
    private java.lang.Long bidUnitId;
    @ApiModelProperty("投标单位")
    private java.lang.String bidUnit;
    @ApiModelProperty("单位负责人id")
    private java.lang.Long unitLeaderId;
    @ApiModelProperty("投标代理人")
    private java.lang.String biddingAgent;
    @ApiModelProperty("单位负责人")
    private java.lang.String unitLeader;
    @ApiModelProperty("质量目标")
    private java.lang.String qualityTarget;
    @ApiModelProperty("投标标段数量")
    private java.lang.Integer bidSectionNumber;
    @ApiModelProperty("中标标段")
    private java.lang.Integer bidWinningSection;
    @ApiModelProperty("备注")
    private java.lang.String remarks;
    @ApiModelProperty("中标通知书返回状态 0 未选择 1 选择")
    private java.lang.Integer notificationStatus;
    @ApiModelProperty("中标单位信息")
    private java.lang.String bidWinnerNews;
    @ApiModelProperty("是否中标")
    private java.lang.Integer isBidWinning;
    private java.lang.String billStateName;
    private java.lang.String bidResultName;


    /**
     * 所属组织
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织
     */
    @ReferDeserialTransfer
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 工程id
     */
    @ReferSerialTransfer(referCode = "bid-enroll")
    public Long getEnrollId() {
        return enrollId;
    }
    /**
     * 工程id
     */
    @ReferDeserialTransfer
    public void setEnrollId(Long enrollId) {
        this.enrollId = enrollId;
    }


    /**
     * 工程编码
     */
    public java.lang.String getEngineeringCode() {
        return engineeringCode;
    }

    /**
     * 工程编码
     */
    public void setEngineeringCode(java.lang.String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    /**
     * 工程名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 开标日期(格式：yyyy-mm-dd)
     */
    public java.util.Date getOpenTenderDate() {
        return openTenderDate;
    }

    /**
     * 开标日期(格式：yyyy-mm-dd)
     */
    public void setOpenTenderDate(java.util.Date openTenderDate) {
        this.openTenderDate = openTenderDate;
    }
    /**
     * 评标办法id  (自定义档案)
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public java.lang.Long getBidEvaluationId() {
        return bidEvaluationId;
    }

    /**
     * 评标办法id  (自定义档案)
     */
    @ReferDeserialTransfer
    public void setBidEvaluationId(java.lang.Long bidEvaluationId) {
        this.bidEvaluationId = bidEvaluationId;
    }
    /**
     * 评标办法  
     */
    public java.lang.String getBidEvaluationMethod() {
        return bidEvaluationMethod;
    }

    /**
     * 评标办法  
     */
    public void setBidEvaluationMethod(java.lang.String bidEvaluationMethod) {
        this.bidEvaluationMethod = bidEvaluationMethod;
    }
    /**
     * 项目负责人
     */
    public java.lang.String getProjectLeader() {
        return projectLeader;
    }

    /**
     * 项目负责人
     */
    public void setProjectLeader(java.lang.String projectLeader) {
        this.projectLeader = projectLeader;
    }
    /**
     * 建造师
     */
    public String getArchitect() {
        return architect;
    }

    /**
     * 建造师
     */
    public void setArchitect(String architect) {
        this.architect = architect;
    }

    /**
     * 投标结果 0 已中标 1 未中标
     */
    public java.lang.Integer getBidResult() {
        return bidResult;
    }

    /**
     * 投标结果 0 已中标 1 未中标
     */
    public void setBidResult(java.lang.Integer bidResult) {
        this.bidResult = bidResult;
    }
    /**
     * 中标单位id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public java.lang.Long getBidWinnerId() {
        return bidWinnerId;
    }

    /**
     * 中标单位id
     */
    @ReferDeserialTransfer
    public void setBidWinnerId(java.lang.Long bidWinnerId) {
        this.bidWinnerId = bidWinnerId;
    }
    /**
     * 中标单位
     */
    public java.lang.String getBidWinner() {
        return bidWinner;
    }

    /**
     * 中标单位
     */
    public void setBidWinner(java.lang.String bidWinner) {
        this.bidWinner = bidWinner;
    }
    /**
     * 施工项目部id
     */
    public String getConstructionProjectDepartmentId() {
        return constructionProjectDepartmentId;
    }
    /**
     * 施工项目部id
     */
    public void setConstructionProjectDepartmentId(String constructionProjectDepartmentId) {
        this.constructionProjectDepartmentId = constructionProjectDepartmentId;
    }

    /**
     * 施工项目部
     */
    public java.lang.String getConstructionProjectDepartment() {
        return constructionProjectDepartment;
    }

    /**
     * 施工项目部
     */
    public void setConstructionProjectDepartment(java.lang.String constructionProjectDepartment) {
        this.constructionProjectDepartment = constructionProjectDepartment;
    }
    /**
     * 开标地点
     */
    public java.lang.String getBidOpeningPlace() {
        return bidOpeningPlace;
    }

    /**
     * 开标地点
     */
    public void setBidOpeningPlace(java.lang.String bidOpeningPlace) {
        this.bidOpeningPlace = bidOpeningPlace;
    }
    /**
     * 中标日期(格式：yyyy-mm-dd)
     */
    public java.util.Date getWinBiddingDate() {
        return winBiddingDate;
    }

    /**
     * 中标日期(格式：yyyy-mm-dd)
     */
    public void setWinBiddingDate(java.util.Date winBiddingDate) {
        this.winBiddingDate = winBiddingDate;
    }
    /**
     * 报价形式 0:总价 1:费率
     */
    public java.lang.String getQuotationForm() {
        return quotationForm;
    }

    /**
     * 报价形式 0:总价 1:费率
     */
    public void setQuotationForm(java.lang.String quotationForm) {
        this.quotationForm = quotationForm;
    }
    /**
     * 中标金额  （单位万元）
     */
    public java.math.BigDecimal getBidMmy() {
        return bidMmy;
    }

    /**
     * 中标金额  （单位万元）
     */
    public void setBidMmy(java.math.BigDecimal bidMmy) {
        this.bidMmy = bidMmy;
    }
    /**
     * 招标控制价（单位万元）
     */
    public java.math.BigDecimal getBiddingControlMmy() {
        return biddingControlMmy;
    }

    /**
     * 招标控制价（单位万元）
     */
    public void setBiddingControlMmy(java.math.BigDecimal biddingControlMmy) {
        this.biddingControlMmy = biddingControlMmy;
    }
    /**
     * 报价下浮率（控制价）% 
     */
    public java.math.BigDecimal getQuoteLowerRate() {
        return quoteLowerRate;
    }

    /**
     * 报价下浮率（控制价）% 
     */
    public void setQuoteLowerRate(java.math.BigDecimal quoteLowerRate) {
        this.quoteLowerRate = quoteLowerRate;
    }
    /**
     * 投标报价费率 
     */
    public java.math.BigDecimal getBidQuotationRate() {
        return bidQuotationRate;
    }

    /**
     * 投标报价费率 
     */
    public void setBidQuotationRate(java.math.BigDecimal bidQuotationRate) {
        this.bidQuotationRate = bidQuotationRate;
    }
    /**
     * 招标控制价费率
     */
    public java.math.BigDecimal getBiddingControlRate() {
        return biddingControlRate;
    }

    /**
     * 招标控制价费率
     */
    public void setBiddingControlRate(java.math.BigDecimal biddingControlRate) {
        this.biddingControlRate = biddingControlRate;
    }
    /**
     * 报价下浮率（控制价）%
     */
    public java.math.BigDecimal getControlQuoteLowerRate() {
        return controlQuoteLowerRate;
    }

    /**
     * 报价下浮率（控制价）%
     */
    public void setControlQuoteLowerRate(java.math.BigDecimal controlQuoteLowerRate) {
        this.controlQuoteLowerRate = controlQuoteLowerRate;
    }
    /**
     * 工期
     */
    public BigDecimal getDuration() {
        return duration;
    }

    /**
     * 工期
     */
    public void setDuration(BigDecimal duration) {
        this.duration = duration;
    }

    /**
     * 投标单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public java.lang.Long getBidUnitId() {
        return bidUnitId;
    }

    /**
     * 投标单位id
     */
    @ReferDeserialTransfer
    public void setBidUnitId(java.lang.Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    /**
     * 投标单位
     */
    public java.lang.String getBidUnit() {
        return bidUnit;
    }

    /**
     * 投标单位
     */
    public void setBidUnit(java.lang.String bidUnit) {
        this.bidUnit = bidUnit;
    }
    /**
     * 单位负责人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getUnitLeaderId() {
        return unitLeaderId;
    }

    /**
     * 单位负责人id
     */
    @ReferDeserialTransfer
    public void setUnitLeaderId(java.lang.Long unitLeaderId) {
        this.unitLeaderId = unitLeaderId;
    }
    /**
     * 单位负责人
     */
    public java.lang.String getUnitLeader() {
        return unitLeader;
    }
    /**
     * 投标代理人
     */
    public String getBiddingAgent() {
        return biddingAgent;
    }
    /**
     * 投标代理人
     */
    public void setBiddingAgent(String biddingAgent) {
        this.biddingAgent = biddingAgent;
    }

    /**
     * 单位负责人
     */
    public void setUnitLeader(java.lang.String unitLeader) {
        this.unitLeader = unitLeader;
    }
    /**
     * 质量目标
     */
    public java.lang.String getQualityTarget() {
        return qualityTarget;
    }

    /**
     * 质量目标
     */
    public void setQualityTarget(java.lang.String qualityTarget) {
        this.qualityTarget = qualityTarget;
    }
    /**
     * 投标标段数量
     */
    public java.lang.Integer getBidSectionNumber() {
        return bidSectionNumber;
    }

    /**
     * 投标标段数量
     */
    public void setBidSectionNumber(java.lang.Integer bidSectionNumber) {
        this.bidSectionNumber = bidSectionNumber;
    }
    /**
     * 中标标段
     */
    public java.lang.Integer getBidWinningSection() {
        return bidWinningSection;
    }

    /**
     * 中标标段
     */
    public void setBidWinningSection(java.lang.Integer bidWinningSection) {
        this.bidWinningSection = bidWinningSection;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 中标通知书返回状态 0 未选择 1 选择
     */
    public java.lang.Integer getNotificationStatus() {
        return notificationStatus;
    }

    /**
     * 中标通知书返回状态 0 未选择 1 选择
     */
    public void setNotificationStatus(java.lang.Integer notificationStatus) {
        this.notificationStatus = notificationStatus;
    }
    /**
     * 中标单位信息
     */
    public java.lang.String getBidWinnerNews() {
        return bidWinnerNews;
    }

    /**
     * 中标单位信息
     */
    public void setBidWinnerNews(java.lang.String bidWinnerNews) {
        this.bidWinnerNews = bidWinnerNews;
    }
    /**
     * 是否中标
     */
    public java.lang.Integer getIsBidWinning() {
        return isBidWinning;
    }

    /**
     * 是否中标
     */
    public void setIsBidWinning(java.lang.Integer isBidWinning) {
        this.isBidWinning = isBidWinning;
    }
    /**
     * 单据状态名字
     */
    public String getBillStateName() {
        return billStateName;
    }
    /**
     * 单据状态名字
     */
    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
    /**
     * 投标结果名字
     */
    public String getBidResultName() {
        return bidResultName;
    }
    /**
     * 投标结果名字
     */
    public void setBidResultName(String bidResultName) {
        this.bidResultName = bidResultName;
    }
}

==> ejc-bid-api-3.0.0-20211125.020024-37-sources.jar: com/ejianc/business/bid/vo/summaryVO.java <==
package com.ejianc.business.bid.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 *   投标总结 
 * 
 * @author generator
 * 
 */
@ApiModel("  投标总结 ")
public class summaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("所属组织")
    private java.lang.Long orgId;
    @ApiModelProperty("所属组织名称")
    private java.lang.String orgName;
    @ApiModelProperty("单据编码")
    private java.lang.String billCode;
    @ApiModelProperty("单据状态")
    private java.lang.Integer billState;
    @ApiModelProperty("工程id")
    private java.lang.Long enrollId;
    @ApiModelProperty("工程编码")
    private java.lang.String engineeringCode;
    @ApiModelProperty("工程名称")
    private java.lang.String engineeringName;
    @ApiModelProperty("开标日期(格式：yyyy-mm-dd)")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date openTenderDate;
    @ApiModelProperty("评标办法id  (自定义档案)")
    private java.lang.Long bidEvaluationId;
    @ApiModelProperty("评标办法")
    private java.lang.String bidEvaluationMethod;
    @ApiModelProperty("项目负责人")
    private java.lang.String projectLeader;
    @ApiModelProperty("建造师")
    private java.lang.String architect;
    @ApiModelProperty("投标结果 0 已中标 1 未中标")
    private java.lang.Integer bidResult;
    @ApiModelProperty("中标单位id")
    private java.lang.Long bidWinnerId;
    @ApiModelProperty("中标单位")
    private java.lang.String bidWinner;
    @ApiModelProperty("施工项目部id")
    private java.lang.String constructionProjectDepartmentId;
    @ApiModelProperty("施工项目部")
    private java.lang.String constructionProjectDepartment;
    @ApiModelProperty("开标地点")
    private java.lang.String bidOpeningPlace;
    @ApiModelProperty("中标日期(格式：yyyy-mm-dd)")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date winBiddingDate;
    @ApiModelProperty("报价形式 0:总价 1:费率")
    private java.lang.String quotationForm;
    @ApiModelProperty("中标金额  （单位万元）")
    private java.math.BigDecimal bidMmy;
    @ApiModelProperty("招标控制价（单位万元）")
    private java.math.BigDecimal biddingControlMmy;
    @ApiModelProperty("报价下浮率（控制价）% ")
    private java.math.BigDecimal quoteLowerRate;
    @ApiModelProperty("投标报价费率 ")
    private java.math.BigDecimal bidQuotationRate;
    @ApiModelProperty("招标控制价费率")
    private java.math.BigDecimal biddingControlRate;
    @ApiModelProperty("报价下浮率（控制价）%")
    private java.math.BigDecimal controlQuoteLowerRate;
    @ApiModelProperty("工期")
    private java.math.BigDecimal duration;
    @ApiModelProperty("投标单位id")
    private java.lang.Long bidUnitId;
    @ApiModelProperty("投标单位")
    private java.lang.String bidUnit;
    @ApiModelProperty("单位负责人id")
    private java.lang.Long unitLeaderId;
    @ApiModelProperty("投标代理人")
    private java.lang.String biddingAgent;
    @ApiModelProperty("单位负责人")
    private java.lang.String unitLeader;
    @ApiModelProperty("质量目标")
    private java.lang.String qualityTarget;
    @ApiModelProperty("投标标段数量")
    private java.lang.Integer bidSectionNumber;
    @ApiModelProperty("中标标段")
    private java.lang.String bidWinningSection;
    @ApiModelProperty("备注")
    private java.lang.String remarks;
    @ApiModelProperty("中标通知书返回状态 0 未选择 1 选择")
    private java.lang.Integer notificationStatus;
    @ApiModelProperty("中标单位信息")
    private java.lang.String bidWinnerNews;
    @ApiModelProperty("是否中标")
    private java.lang.Integer isBidWinning;
    private java.lang.String billStateName;
    private java.lang.String bidResultName;


    /**
     * 所属组织
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织
     */
    @ReferDeserialTransfer
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 工程id
     */
    @ReferSerialTransfer(referCode = "bid-enroll")
    public Long getEnrollId() {
        return enrollId;
    }
    /**
     * 工程id
     */
    @ReferDeserialTransfer
    public void setEnrollId(Long enrollId) {
        this.enrollId = enrollId;
    }


    /**
     * 工程编码
     */
    public java.lang.String getEngineeringCode() {
        return engineeringCode;
    }

    /**
     * 工程编码
     */
    public void setEngineeringCode(java.lang.String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    /**
     * 工程名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 开标日期(格式：yyyy-mm-dd)
     */
    public java.util.Date getOpenTenderDate() {
        return openTenderDate;
    }

    /**
     * 开标日期(格式：yyyy-mm-dd)
     */
    public void setOpenTenderDate(java.util.Date openTenderDate) {
        this.openTenderDate = openTenderDate;
    }
    /**
     * 评标办法id  (自定义档案)
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public java.lang.Long getBidEvaluationId() {
        return bidEvaluationId;
    }

    /**
     * 评标办法id  (自定义档案)
     */
    @ReferDeserialTransfer
    public void setBidEvaluationId(java.lang.Long bidEvaluationId) {
        this.bidEvaluationId = bidEvaluationId;
    }
    /**
     * 评标办法  
     */
    public java.lang.String getBidEvaluationMethod() {
        return bidEvaluationMethod;
    }

    /**
     * 评标办法  
     */
    public void setBidEvaluationMethod(java.lang.String bidEvaluationMethod) {
        this.bidEvaluationMethod = bidEvaluationMethod;
    }
    /**
     * 项目负责人
     */
    public java.lang.String getProjectLeader() {
        return projectLeader;
    }

    /**
     * 项目负责人
     */
    public void setProjectLeader(java.lang.String projectLeader) {
        this.projectLeader = projectLeader;
    }
    /**
     * 建造师
     */
    public String getArchitect() {
        return architect;
    }

    /**
     * 建造师
     */
    public void setArchitect(String architect) {
        this.architect = architect;
    }

    /**
     * 投标结果 0 已中标 1 未中标
     */
    public java.lang.Integer getBidResult() {
        return bidResult;
    }

    /**
     * 投标结果 0 已中标 1 未中标
     */
    public void setBidResult(java.lang.Integer bidResult) {
        this.bidResult = bidResult;
    }
    /**
     * 中标单位id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public java.lang.Long getBidWinnerId() {
        return bidWinnerId;
    }

    /**
     * 中标单位id
     */
    @ReferDeserialTransfer
    public void setBidWinnerId(java.lang.Long bidWinnerId) {
        this.bidWinnerId = bidWinnerId;
    }
    /**
     * 中标单位
     */
    public java.lang.String getBidWinner() {
        return bidWinner;
    }

    /**
     * 中标单位
     */
    public void setBidWinner(java.lang.String bidWinner) {
        this.bidWinner = bidWinner;
    }
    /**
     * 施工项目部id
     */
    public String getConstructionProjectDepartmentId() {
        return constructionProjectDepartmentId;
    }
    /**
     * 施工项目部id
     */
    public void setConstructionProjectDepartmentId(String constructionProjectDepartmentId) {
        this.constructionProjectDepartmentId = constructionProjectDepartmentId;
    }

    /**
     * 施工项目部
     */
    public java.lang.String getConstructionProjectDepartment() {
        return constructionProjectDepartment;
    }

    /**
     * 施工项目部
     */
    public void setConstructionProjectDepartment(java.lang.String constructionProjectDepartment) {
        this.constructionProjectDepartment = constructionProjectDepartment;
    }
    /**
     * 开标地点
     */
    public java.lang.String getBidOpeningPlace() {
        return bidOpeningPlace;
    }

    /**
     * 开标地点
     */
    public void setBidOpeningPlace(java.lang.String bidOpeningPlace) {
        this.bidOpeningPlace = bidOpeningPlace;
    }
    /**
     * 中标日期(格式：yyyy-mm-dd)
     */
    public java.util.Date getWinBiddingDate() {
        return winBiddingDate;
    }

    /**
     * 中标日期(格式：yyyy-mm-dd)
     */
    public void setWinBiddingDate(java.util.Date winBiddingDate) {
        this.winBiddingDate = winBiddingDate;
    }
    /**
     * 报价形式 0:总价 1:费率
     */
    public java.lang.String getQuotationForm() {
        return quotationForm;
    }

    /**
     * 报价形式 0:总价 1:费率
     */
    public void setQuotationForm(java.lang.String quotationForm) {
        this.quotationForm = quotationForm;
    }
    /**
     * 中标金额  （单位万元）
     */
    public java.math.BigDecimal getBidMmy() {
        return bidMmy;
    }

    /**
     * 中标金额  （单位万元）
     */
    public void setBidMmy(java.math.BigDecimal bidMmy) {
        this.bidMmy = bidMmy;
    }
    /**
     * 招标控制价（单位万元）
     */
    public java.math.BigDecimal getBiddingControlMmy() {
        return biddingControlMmy;
    }

    /**
     * 招标控制价（单位万元）
     */
    public void setBiddingControlMmy(java.math.BigDecimal biddingControlMmy) {
        this.biddingControlMmy = biddingControlMmy;
    }
    /**
     * 报价下浮率（控制价）% 
     */
    public java.math.BigDecimal getQuoteLowerRate() {
        return quoteLowerRate;
    }

    /**
     * 报价下浮率（控制价）% 
     */
    public void setQuoteLowerRate(java.math.BigDecimal quoteLowerRate) {
        this.quoteLowerRate = quoteLowerRate;
    }
    /**
     * 投标报价费率 
     */
    public java.math.BigDecimal getBidQuotationRate() {
        return bidQuotationRate;
    }

    /**
     * 投标报价费率 
     */
    public void setBidQuotationRate(java.math.BigDecimal bidQuotationRate) {
        this.bidQuotationRate = bidQuotationRate;
    }
    /**
     * 招标控制价费率
     */
    public java.math.BigDecimal getBiddingControlRate() {
        return biddingControlRate;
    }

    /**
     * 招标控制价费率
     */
    public void setBiddingControlRate(java.math.BigDecimal biddingControlRate) {
        this.biddingControlRate = biddingControlRate;
    }
    /**
     * 报价下浮率（控制价）%
     */
    public java.math.BigDecimal getControlQuoteLowerRate() {
        return controlQuoteLowerRate;
    }

    /**
     * 报价下浮率（控制价）%
     */
    public void setControlQuoteLowerRate(java.math.BigDecimal controlQuoteLowerRate) {
        this.controlQuoteLowerRate = controlQuoteLowerRate;
    }
    /**
     * 工期
     */
    public BigDecimal getDuration() {
        return duration;
    }

    /**
     * 工期
     */
    public void setDuration(BigDecimal duration) {
        this.duration = duration;
    }

    /**
     * 投标单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public java.lang.Long getBidUnitId() {
        return bidUnitId;
    }

    /**
     * 投标单位id
     */
    @ReferDeserialTransfer
    public void setBidUnitId(java.lang.Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    /**
     * 投标单位
     */
    public java.lang.String getBidUnit() {
        return bidUnit;
    }

    /**
     * 投标单位
     */
    public void setBidUnit(java.lang.String bidUnit) {
        this.bidUnit = bidUnit;
    }
    /**
     * 单位负责人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getUnitLeaderId() {
        return unitLeaderId;
    }

    /**
     * 单位负责人id
     */
    @ReferDeserialTransfer
    public void setUnitLeaderId(java.lang.Long unitLeaderId) {
        this.unitLeaderId = unitLeaderId;
    }
    /**
     * 单位负责人
     */
    public java.lang.String getUnitLeader() {
        return unitLeader;
    }
    /**
     * 投标代理人
     */
    public String getBiddingAgent() {
        return biddingAgent;
    }
    /**
     * 投标代理人
     */
    public void setBiddingAgent(String biddingAgent) {
        this.biddingAgent = biddingAgent;
    }

    /**
     * 单位负责人
     */
    public void setUnitLeader(java.lang.String unitLeader) {
        this.unitLeader = unitLeader;
    }
    /**
     * 质量目标
     */
    public java.lang.String getQualityTarget() {
        return qualityTarget;
    }

    /**
     * 质量目标
     */
    public void setQualityTarget(java.lang.String qualityTarget) {
        this.qualityTarget = qualityTarget;
    }
    /**
     * 投标标段数量
     */
    public java.lang.Integer getBidSectionNumber() {
        return bidSectionNumber;
    }

    /**
     * 投标标段数量
     */
    public void setBidSectionNumber(java.lang.Integer bidSectionNumber) {
        this.bidSectionNumber = bidSectionNumber;
    }
    /**
     * 中标标段
     */
    public String getBidWinningSection() {
        return bidWinningSection;
    }

    /**
     * 中标标段
     */
    public void setBidWinningSection(String bidWinningSection) {
        this.bidWinningSection = bidWinningSection;
    }

    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 中标通知书返回状态 0 未选择 1 选择
     */
    public java.lang.Integer getNotificationStatus() {
        return notificationStatus;
    }

    /**
     * 中标通知书返回状态 0 未选择 1 选择
     */
    public void setNotificationStatus(java.lang.Integer notificationStatus) {
        this.notificationStatus = notificationStatus;
    }
    /**
     * 中标单位信息
     */
    public java.lang.String getBidWinnerNews() {
        return bidWinnerNews;
    }

    /**
     * 中标单位信息
     */
    public void setBidWinnerNews(java.lang.String bidWinnerNews) {
        this.bidWinnerNews = bidWinnerNews;
    }
    /**
     * 是否中标
     */
    public java.lang.Integer getIsBidWinning() {
        return isBidWinning;
    }

    /**
     * 是否中标
     */
    public void setIsBidWinning(java.lang.Integer isBidWinning) {
        this.isBidWinning = isBidWinning;
    }
    /**
     * 单据状态名字
     */
    public String getBillStateName() {
        return billStateName;
    }
    /**
     * 单据状态名字
     */
    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
    /**
     * 投标结果名字
     */
    public String getBidResultName() {
        return bidResultName;
    }
    /**
     * 投标结果名字
     */
    public void setBidResultName(String bidResultName) {
        this.bidResultName = bidResultName;
    }
}
